==> iterable-utilities-2.5.0.tgz: package/esm/fp.js <==
import { curryIterFunction } from "./lib/internal/util.js";
import * as combinators from "./lib/combiners.js";
import * as reducers from "./lib/reducers.js";
import * as transformers from "./lib/transformers.js";
import * as effectors from "./lib/effectors.js";
// Combinators
export const pair = curryIterFunction(combinators.pair);
export const concat = curryIterFunction(combinators.concat);
// Reducers
export const reduce = curryIterFunction(reducers.reduce);
export const some = curryIterFunction(reducers.some);
export const includes = curryIterFunction(reducers.includes);
export const every = curryIterFunction(reducers.every);
export const find = curryIterFunction(reducers.find);
export const sum = reducers.sum;
export const product = reducers.product;
export const norm = reducers.norm;
// Transformers
export const map = curryIterFunction(transformers.map);
export const take = curryIterFunction(transformers.take);
export const until = curryIterFunction(transformers.until);
export const filter = curryIterFunction(transformers.filter);
export const indexedPairs = transformers.indexedPairs;
export const chunkify = curryIterFunction(transformers.chunkify);
export const remember = transformers.rememeber;
export const flat = curryIterFunction(transformers.flat);
export const completeFlat = transformers.completeFlat;
// Effectors
export const forEach = curryIterFunction(effectors.forEach);
export const lazyObserver = curryIterFunction(effectors.lazyObserver);
export * as create from "./lib/generators.js";

==> iterable-utilities-3.0.0.tgz: package/esm/fp.js <==
export { LICENSE, VERSION } from "./version.js";
import { curryIterFunction } from "./lib/internal/util.js";
import * as combinators from "./lib/combiners.js";
import * as reducers from "./lib/reducers.js";
import * as transformers from "./lib/transformers.js";
import * as effectors from "./lib/effectors.js";
// Combinators
export const pair = curryIterFunction(combinators.pair);
export const concat = curryIterFunction(combinators.concat);
// Reducers
export const reduce = curryIterFunction(reducers.reduce);
export const some = curryIterFunction(reducers.some);
export const every = curryIterFunction(reducers.every);
export const includes = curryIterFunction(reducers.includes);
export const find = curryIterFunction(reducers.find);
export const findIndex = curryIterFunction(reducers.findIndex);
export const sum = reducers.sum;
export const product = reducers.product;
export const norm = reducers.norm;
// Transformers
export const map = curryIterFunction(transformers.map);
export const take = curryIterFunction(transformers.take);
export const until = curryIterFunction(transformers.until);
export const filter = curryIterFunction(transformers.filter);
export const indexedPairs = transformers.indexedPairs;
export const chunkify = curryIterFunction(transformers.chunkify);
export const remember = transformers.remember;
export const flat = curryIterFunction(transformers.flat);
export const completeFlat = transformers.completeFlat;
export const fuse = transformers.fuse;
export const peekable = transformers.peekable;
// Effectors
export const forEach = curryIterFunction(effectors.forEach);
export const lazyObserver = curryIterFunction(effectors.lazyObserver);
export * as create from "./lib/generators.js";
